package stamp.util.history;
import stamp.core.*;

/**
 * This class extends class History() for use with systen eeprom.
 *
 * @version 1.0, November 17, 2008
 * @author Peter Verkaik (verkaik6@zonnet.nl)
 */

public class SystemEepromHistory extends History {

  private int offset;

  /**
   * Constructor.
   *
   * @param offset Start address of message table in system eeprom
   * @param size Length of message table in bytes
   */
  public SystemEepromHistory(int offset, int size) {
    super(size);
    this.offset = offset;
    init();
  }

  /**
   * Read byte from eeprom.
   *
   * @param addr Address to read byte from.
   * @return Byte value from address.
   */
  protected int readByte(int addr) {
    return JavEE.readByte(addr+offset);
  }

  /**
   * Write byte to eeprom.
   *
   * @param addr Address to write byte into.
   * @param val Byte value to write.
   */
  protected void writeByte(int addr, int val) {
    JavEE.writeByte(addr+offset,val);
  }

  /**
   * Read word from eeprom.
   *
   * @param addr Address to read word from.
   * @return Word value from address.
   */
  protected int readWord(int addr) {
    return JavEE.readWord(addr+offset);
  }

  /**
   * Write word to eeprom.
   *
   * @param addr Address to write word into.
   * @param val Word value to write.
   */
  protected void writeWord(int addr, int val) {
    JavEE.writeWord(addr+offset,val);
  }

}