package stamp.util.history;

/**
 * This class extends class History() for use with systen ram.
 *
 * @version 1.0, November 17, 2008
 * @author Peter Verkaik (verkaik6@zonnet.nl)
 */

public class SystemRamHistory extends History {

  private char[] mem;
  private int size;

  /**
   * Constructor.
   *
   * @param size Length of message table in bytes
   */
  public SystemRamHistory(int size) {
    super(size);
    mem = new char[size];
    init();
  }

  /**
   * Read byte from ram.
   *
   * @param addr Address to read byte from.
   * @return Byte value from address.
   */
  protected int readByte(int addr) {
    return mem[addr] & 0xFF;
  }

  /**
   * Write byte to ram.
   *
   * @param addr Address to write byte into.
   * @param val Byte value to write.
   */
  protected void writeByte(int addr, int val) {
    mem[addr] = (char)val;
  }

  /**
   * Read word from ram.
   *
   * @param addr Address to read word from.
   * @return Word value from address.
   */
  protected int readWord(int addr) {
    return (mem[addr] & 0xFF) | (mem[addr+1] << 8);
  }

  /**
   * Write word to ram.
   *
   * @param addr Address to write word into.
   * @param val Word value to write.
   */
  protected void writeWord(int addr, int val) {
    mem[addr] = (char)val;
    mem[addr+1] = (char)(val>>>8);
  }

}